//
//  GlanceController.swift
//  DisplayingGlances WatchKit Extension
//
//  Created by Wei-Meng Lee on 29/4/15.
//  Copyright (c) 2015 Wei-Meng Lee. All rights reserved.
//

import WatchKit
import Foundation


class GlanceController: WKInterfaceController {

    @IBOutlet weak var lblSymbol: WKInterfaceLabel!
    @IBOutlet weak var lblLastUpdate: WKInterfaceLabel!
    @IBOutlet weak var lblAsk: WKInterfaceLabel!
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        
        // Configure interface objects here.
        println("glances - awakeWithContext:")
    }

    //---convert from string to NSDate---
    func dateStringToDate(date:String) -> NSDate {
        var dateFormatter = NSDateFormatter()
        dateFormatter.dateFormat = "yyyy-MM-dd HH:mm:ss zzz"
        return dateFormatter.dateFromString(date)!
    }
    
    override func willActivate() {
        // This method is called when watch view controller is about to be visible to user
        super.willActivate()
        println("glances - willActivate")
        
        var defaults = NSUserDefaults(suiteName: "group.learningwatchkit.displayingglances.app")
        
        //---retrieve the price and date fetched from the settings---
        var priceAndDate = defaults?.objectForKey("AAPL") as! [String:String]
        
        var price = priceAndDate["ask"]!
        var dateFetched = dateStringToDate(priceAndDate["date"]!)
        
        //---the difference between the current time and the time the price was fetched---
        let elapsedTime = NSDate().timeIntervalSinceDate(dateFetched)
        
        //---convert to seconds---
        let elapsedTimeSeconds = Int(elapsedTime)
        
        //---convert the time to mins and secs---
        let elapsedMin = elapsedTimeSeconds / 60
        let elapsedSec = elapsedTimeSeconds % 60
        
        if elapsedMin > 0 {
            lblLastUpdate.setText(
            "\(elapsedMin) mins \(Int(elapsedSec)) secs")
        } else {
            lblLastUpdate.setText("\(Int(elapsedTime)) secs")
        }
        //---show the info on the glance---
        self.lblSymbol.setText("AAPL")
        self.lblAsk.setText("$" + price)
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
        println("glances - didDeactivate")
    }

}
