//
//  GetCurrentLocation.swift
//  GetSingleLocation
//
//  Created by Wei-Meng Lee on 12/4/15.
//  Copyright (c) 2015 Wei-Meng Lee. All rights reserved.
//

import Foundation
import CoreLocation

class GetCurrentLocation:NSObject, CLLocationManagerDelegate {
    var lm: CLLocationManager!
    
    //---the closure that is fired containing the location obtained
    // and error (if any)---
    typealias LocationObtainedClosure = (
        (location: CLLocation?, error: NSError?)->()
    )
    var didCompleteHandler: LocationObtainedClosure!
    
    //---when a location has been found---
    func locationManager(manager: CLLocationManager!,
        didUpdateLocations locations: [AnyObject]!) {
                      
        //---stop finding location---
        lm.stopUpdatingLocation()
            
        //---get the most recent location---
        var currentLocation = locations.last as! CLLocation
            
        //---inform the caller and pass it the location---
        didCompleteHandler(location: currentLocation, error: nil)
            
        //---set the lm and delegate to nil---
        lm.delegate = nil
        lm = nil
    }
    
    //---failed to find a location---
    func locationManager(manager: CLLocationManager!,
        didFailWithError error: NSError!) {
            
        //---report the error to the caller---
        didCompleteHandler(location: nil, error: error)
    }
    
    //---caller will call this function and implement the 
    // closure to get the single location---
    func getLocationWithCompletion(completion: LocationObtainedClosure) {
        didCompleteHandler = completion

        lm = CLLocationManager()
        lm.delegate = self
        lm.desiredAccuracy = 0
        lm.distanceFilter = 0
        lm.startUpdatingLocation()
    }
    
}


