//
//  AppDelegate.swift
//  WebServices
//
//  Created by Wei-Meng Lee on 13/4/15.
//  Copyright (c) 2015 Wei-Meng Lee. All rights reserved.
//

import UIKit

@UIApplicationMain
class AppDelegate: UIResponder, UIApplicationDelegate {
    
    var window: UIWindow?
    var taskID: UIBackgroundTaskIdentifier!
    
    //---parse the json string---
    func parseJSONData(data: NSData) -> Double {
        var error: NSError?
        var parsedJSONData = NSJSONSerialization.JSONObjectWithData(data,
            options: NSJSONReadingOptions.allZeros,
            error: &error) as! NSDictionary
        
        var main = parsedJSONData["main"] as! NSDictionary
        
        //---temperature in Kelvin---
        var temp = main["temp"] as! Double
        
        //---convert temperature to Celcius---
        return temp - 273;
    }
    
    func application(application: UIApplication,
            handleWatchKitExtensionRequest userInfo: [NSObject : AnyObject]?,
            reply: (([NSObject : AnyObject]!) -> Void)!) {
    
        //---cast the data from the extension as a dictionary---
        var dataFromPhone = userInfo! as NSDictionary
            
        //---url of the web service---
        var urlString = "http://api.openweathermap.org/data/2.5/weather?q=" +
            (dataFromPhone["country"] as! String).stringByAddingPercentEncodingWithAllowedCharacters(.URLHostAllowedCharacterSet())!
                
        var session = NSURLSession.sharedSession()
        
        //---start a background task with expiration---
        taskID = application.beginBackgroundTaskWithName("backgroundTask",
            expirationHandler: { () -> Void in
            if self.taskID != UIBackgroundTaskInvalid {
                application.endBackgroundTask(self.taskID)
                self.taskID = UIBackgroundTaskInvalid
            }
        })
            
        session.dataTaskWithURL(NSURL(string:urlString)!,
            completionHandler: {
            (data, response, error) -> Void in
                
            var httpResp = response as! NSHTTPURLResponse
            if error == nil && httpResp.statusCode == 200 {
                var result = NSString(bytes: data.bytes,
                    length: data.length, encoding: NSUTF8StringEncoding)
            
                //---parse the JSON result---
                var temp = self.parseJSONData(data)
            
                //---send the temp back to the extension---
                var dataToWatch = [
                    "temp" : temp
                ]
                reply(dataToWatch)
            } else {
                reply([:])
            }
                
            //---end the background task---
            application.endBackgroundTask(self.taskID)
            self.taskID = UIBackgroundTaskInvalid
        }).resume()
    }
    
    func application(application: UIApplication, didFinishLaunchingWithOptions launchOptions: [NSObject: AnyObject]?) -> Bool {
                // Override point for customization after application launch.
                return true
    }
    
    func applicationWillResignActive(application: UIApplication) {
            // Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
            // Use this method to pause ongoing tasks, disable timers, and throttle down OpenGL ES frame rates. Games should use this method to pause the game.
    }
    
    func applicationDidEnterBackground(application: UIApplication) {
        // Use this method to release shared resources, save user data, invalidate timers, and store enough application state information to restore your application to its current state in case it is terminated later.
        // If your application supports background execution, this method is called instead of applicationWillTerminate: when the user quits.
    }
    
    func applicationWillEnterForeground(application: UIApplication) {
        // Called as part of the transition from the background to the inactive state; here you can undo many of the changes made on entering the background.
    }
    
    func applicationDidBecomeActive(application: UIApplication) {
        // Restart any tasks that were paused (or not yet started) while the application was inactive. If the application was previously in the background, optionally refresh the user interface.
    }
    
    func applicationWillTerminate(application: UIApplication) {
            // Called when the application is about to terminate. Save data if appropriate. See also applicationDidEnterBackground:.
    }
    
    
}

