//
//  ViewController.swift
//  WebServices
//
//  Created by Wei-Meng Lee on 13/4/15.
//  Copyright (c) 2015 Wei-Meng Lee. All rights reserved.
//

import UIKit

class ViewController: UIViewController,
    UIPickerViewDataSource,
    UIPickerViewDelegate {
    
    @IBOutlet weak var pickerCountries: UIPickerView!
    
    var countries: [String]!
    
    //---download image from the Web---
    func downloadImage(urlString:String) {
        var imgURL = NSURL(string: urlString)
        var request: NSURLRequest = NSURLRequest(URL: imgURL!)
        var urlConnection = NSURLConnection(request: request, delegate: self)
        
        NSURLConnection.sendAsynchronousRequest(request,
            queue: NSOperationQueue.mainQueue(),
            completionHandler: {
                (response: NSURLResponse!,data: NSData!,error: NSError!) -> Void in
                
                if (error == nil) {
                    //---get the content of the file and return as NSData---
                    var imgData = NSData(contentsOfURL: imgURL!)
                    
                    //---get the shared app group URL---
                    var fileManager = NSFileManager.defaultManager()
                    var storeUrl = fileManager.containerURLForSecurityApplicationGroupIdentifier(
                        "group.learningwatchkit.webservices.app")
                    
                    //---save the file using this name---
                    var fileURL = storeUrl?.URLByAppendingPathComponent("image.png")
                    
                    //---save the file to the shared app group---
                    imgData?.writeToURL(fileURL!, atomically: true)
                }
                else {
                    println("Error: \(error.localizedDescription)")
                }
        })
    }
    
    func pickerView(pickerView: UIPickerView, didSelectRow row: Int,
        inComponent component: Int) {
            var defaults = NSUserDefaults(suiteName: "group.learningwatchkit.webservices.app")
            defaults?.setObject(countries[row], forKey: "country")
            defaults?.synchronize()
            
            //---download the flag of the country selected---
            switch countries[row] {
            case "Singapore": downloadImage(
                "https://dl.dropboxusercontent.com/u/37098169/Flags/flag_singapore.png")
            case "Norway": downloadImage(
                "https://dl.dropboxusercontent.com/u/37098169/Flags/flag_norway.png")
            case "Japan": downloadImage(
                "https://dl.dropboxusercontent.com/u/37098169/Flags/flag_japan.png")
            case "Thailand": downloadImage(
                "https://dl.dropboxusercontent.com/u/37098169/Flags/flag_thailand.png")
            case "Hong Kong": downloadImage(
                "https://dl.dropboxusercontent.com/u/37098169/Flags/flag_hong_kong.png")
            default: break;
            }
    }

    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        countries = ["Singapore", "Norway", "Japan", "Thailand", "Hong Kong"]
        self.pickerCountries.delegate = self
        self.pickerCountries.dataSource = self
    }
    
    func numberOfComponentsInPickerView(pickerView: UIPickerView) -> Int {
        return 1
    }

    func pickerView(pickerView: UIPickerView,
            numberOfRowsInComponent component: Int) -> Int {
        return countries.count
    }
    
    func pickerView(pickerView: UIPickerView, titleForRow row: Int,
            forComponent component: Int) -> String! {
        return countries[row]
    }
    
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    
}

